package com.bpcl.lpg.core.cronjob;

import org.slf4j.LoggerFactory;
import de.hybris.platform.cronjob.model.CronJobModel;
import com.bpcl.lpg.core.model.LpgPaymentInfoModel;
import java.util.List;
import de.hybris.platform.cronjob.enums.CronJobStatus;
import de.hybris.platform.cronjob.enums.CronJobResult;
import de.hybris.platform.servicelayer.exceptions.ModelRemovalException;
import de.hybris.platform.servicelayer.media.NoDataAvailableException;
import java.util.Collection;
import org.apache.commons.collections.CollectionUtils;
import de.hybris.platform.servicelayer.cronjob.PerformResult;
import de.hybris.platform.servicelayer.model.ModelService;
import com.bpcl.lpg.core.payment.billdesk.dao.LPGPaymentInfoDao;
import org.slf4j.Logger;
import com.bpcl.core.model.BpclCronjobModel;
import de.hybris.platform.servicelayer.cronjob.AbstractJobPerformable;

public class TransactionCleanUpJob extends AbstractJobPerformable<BpclCronjobModel>
{
    private static final Logger LOG;
    private LPGPaymentInfoDao lpgPaymentInfoDao;
    private ModelService modelService;
    
    public PerformResult perform(final BpclCronjobModel cronJobModel) {
        try {
            final List<LpgPaymentInfoModel> lpgPaymentInfoModels = this.lpgPaymentInfoDao.getJunkTransaction(cronJobModel.getFilterStartDate(), cronJobModel.getFilterEndDate());
            TransactionCleanUpJob.LOG.info("Number of transactions to be clean up : {}", (Object)lpgPaymentInfoModels.size());
            if (CollectionUtils.isNotEmpty((Collection)lpgPaymentInfoModels)) {
                this.modelService.removeAll((Collection)lpgPaymentInfoModels);
            }
        }
        catch (final NoDataAvailableException ndaEx) {
            TransactionCleanUpJob.LOG.info(ndaEx.getMessage());
        }
        catch (final ModelRemovalException modelRemovalException) {
            TransactionCleanUpJob.LOG.info(modelRemovalException.getMessage());
        }
        catch (final Exception ex) {
            TransactionCleanUpJob.LOG.error(ex.getMessage(), ex.getCause());
            return new PerformResult(CronJobResult.FAILURE, CronJobStatus.ABORTED);
        }
        return new PerformResult(CronJobResult.SUCCESS, CronJobStatus.FINISHED);
    }
    
    public boolean isAbortable() {
        return true;
    }
    
    public void setLpgPaymentInfoDao(final LPGPaymentInfoDao lpgPaymentInfoDao) {
        this.lpgPaymentInfoDao = lpgPaymentInfoDao;
    }
    
    public void setModelService(final ModelService modelService) {
        this.modelService = modelService;
    }
    
    static {
        LOG = LoggerFactory.getLogger(TransactionCleanUpJob.class);
    }
}
